:mod:`collective.celery` Package
================================

.. automodule:: collective.celery
    :members:
    :undoc-members:
    :show-inheritance:

    .. autodata:: task


.. automodule:: collective.celery.base_task
    :members:
    :undoc-members:
    :show-inheritance:


.. automodule:: collective.celery.functionrunner
    :members:
    :undoc-members:
    :show-inheritance:


.. automodule:: collective.celery.utils
    :members:
    :undoc-members:
    :show-inheritance:


.. automodule:: collective.celery.testing
    :members:
    :undoc-members:
    :show-inheritance:
